import 'dart:convert';

import 'package:fis_jsonrpc/services/exam.m.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:flutter_inappwebview/flutter_inappwebview.dart';
import 'package:get/get.dart';
import 'package:vnoteapp/architecture/defines.dart';
import 'package:vnoteapp/architecture/storage/text_storage.dart';
import 'package:vnoteapp/architecture/utils/prompt_box.dart';
import 'package:vnoteapp/managers/interfaces/exam.dart';
import 'package:vnoteapp/managers/interfaces/health_check_record.dart';
import 'package:vnoteapp/pages/check/healthCheckRecord/state.dart';
import 'package:vnoteapp/store/store.dart';

class HealthCheckRecordController extends FControllerBase {
  HealthCheckRecordController();
  final state = HealthCheckRecordState();
  final _healthCheckRecordManager = Get.find<IHealthCehckRecordManager>();
  final _examManager = Get.find<IExamManager>();

  late String patientCode;
  @override
  void onReady() {
    super.onReady();
    _initData();
  }

  _initData() {
    update(["contract_records"]);
    // final p = Get.parameters;
    // patientCode = p['patientCode'] ?? "";
    patientCode = Store.user.currentSelectPatientInfo?.code ?? '';
    _getExamRecordList();
  }

  Future<void> _getExamRecordList() async {
    try {
      var result =
          await _healthCheckRecordManager.getExamRecordList(patientCode);
      if (result != null) {
        state.examRecordDTOList = result;
        for (var element in result) {
          print(element.toJson());
        }
      }
    } catch (e) {
      return;
    }
  }

  Future<void> editExam(key, code, data) async {
    TextStorage template = TextStorage(
      fileName: key,
      directory: "patient/$patientCode/exam",
    );
    final result = await _examManager.editExam(UpdateExamRequest(
      key: key,
      code: code,
      examData: data,
    ));
    if (result ?? false) {
      try {
        template.save(data);
        PromptBox.toast('保存成功');
      } catch (err) {
        print('🥟');
        PromptBox.toast('保存失败');
      }
    }
  }

  ///读取静态Html
  Future<String> loadingLocalAsset() async {
    ///加载
    String htmlData = await rootBundle.loadString('assets/docs/examTable.html');
    print("加载数据完成 $htmlData");
    return htmlData;
  }

  Future<void> toExamDetailPage(int index, ExamRecordDTO dto) async {
    var initialData = await loadingLocalAsset();
    // 获取 InAppWebViewController 实例
    InAppWebViewController webViewController;
    var examRecordDatas = state.examRecordDTOList[index].examRecordDatas;
    Map<String, dynamic> examData = {};
    examRecordDatas?.forEach((element) {
      print(element.toJson());
      examData.addAll(jsonDecode(element.examData ?? '{}'));
    });
// 将数据转换为 JSON 字符串
    var jsonData = jsonEncode({
      "patientInfo": {
        "patientName": dto.patientName,
      },
      "examData": examData,
      "docterName": dto.examDoctor,
      "examTime": "dto.examTime"
    });

// 将 JSON 字符串作为参数传递给 evaluateJavascript 方法
    Get.dialog(InAppWebView(
      initialData: InAppWebViewInitialData(
        data: '<body style="padding: 100px;">$initialData </body>',
        mimeType: 'text/html',
        encoding: 'utf-8',
      ),
      onWebViewCreated: (controller) {
        webViewController = controller;
        controller.evaluateJavascript(source: "window.globalData = $jsonData;");
      },
      // onPageCommitVisible: (controller, url) {
      //   // 在这里执行 JavaScript 代码，并传递数据
      //   controller.evaluateJavascript(source: "window.globalData = $jsonData;");
      // },
      onConsoleMessage: (controller, consoleMessage) {
        // print(consoleMessage);
      },
    ));
  }

  Future<void> toCheckPage(ExamRecordDataDTO dataDTO) async {
    var initialData = await loadingLocalAsset();
// 获取 InAppWebViewController 实例
    InAppWebViewController webViewController;

// 将数据转换为 JSON 字符串
    var jsonData = jsonEncode({
      "patientInfo": {
        "key": "ZZYBZK",
        "patientCode": "59b46779eea5427f8a92126fd3c2a019",
        "contractedDoctor": "finlay1",
        "examData": "",
        "patientName": "王艺兴",
        "cardNo": "321383199809174258",
        "patientGender": "男",
        "patientAddress": "江苏省苏州市吴中区木渎镇金枫南路凤凰村",
        "birthday": "1998-09-17",
        "examState": "已体检",
        "examTime": "2023-11-21",
        "code": "24be089725e84c7b8fee1367c290d6d7",
        "createTime": "2023-11-21T09:12:34.185Z",
        "updateTime": "2023-11-21T09:12:34.185Z",
        "id": 2
      },
      "examData": {
        "Temperature": "26",
        "Fasting_Glucose_Mmol": "1.6",
        "Blood_Hgb": "120",
        "Blood_Wbc": "129",
        "Blood_Rlt": "16",
        "Blood_Routine_Other": "测试数据",
        "Urinary_Pro": "59",
        "Urinary_Glu": "7",
        "Urinary_Key": "67",
        "Liver_Alt": "3",
        "Renal_Cr": "78",
        "Chest_X_Ray": "1",
        "B_Ultrasonic": "1",
        "Cervical_Smear": "1",
        "B_Us_Other": "1"
      },
      "docterName": "finlay1",
      "examTime": "2023-11-21"
    });

// 将 JSON 字符串作为参数传递给 evaluateJavascript 方法
    Get.dialog(InAppWebView(
      initialData: InAppWebViewInitialData(
        data: '<body style="padding: 100px;">$initialData </body>',
        mimeType: 'text/html',
        encoding: 'utf-8',
      ),
      onWebViewCreated: (controller) {
        webViewController = controller;
        controller.evaluateJavascript(source: "window.globalData = $jsonData;");
      },
      // onPageCommitVisible: (controller, url) {
      //   // 在这里执行 JavaScript 代码，并传递数据
      //   controller.evaluateJavascript(source: "window.globalData = $jsonData;");
      // },
      onConsoleMessage: (controller, consoleMessage) {
        print(consoleMessage);
      },
    ));
    // Get.to(
    //   ConfigurableCard(
    //     cardKey: dataDTO.key!,
    //     examData: dataDTO.examData,
    //     callBack: (key, templateCode, data) async {
    //       await editExam(key, dataDTO.code, data);
    //       _getExamRecordList();
    //     },
    //     patientCode: Store.user.currentSelectPatientInfo!.code,
    //   ),
    //   transition: Transition.rightToLeft,
    // );
  }

  String getHealthCheckRecordType(String key) {
    switch (key) {
      case 'ZZYBZK':
        return '症状、一般状况';
      case 'SHFS':
        return '生活方式';
      case 'ZQCT':
        return '脏器、查体';
      case 'FZJC':
        return '辅助检查';
      case 'XCZYWT':
        return '现存主要问题';
      case 'ZYYYFMYGHYFJZS':
        return '住院、用药、非免疫规划预防接种史';
      case 'JKPJJZD':
        return '健康评价及指导';
      default:
        return "";
    }
  }

  String examStateTransition(ExamStateEnum state) {
    switch (state) {
      case ExamStateEnum.Unchecked:
        return "未体检";
      case ExamStateEnum.Invalid:
        return "已作废";
      case ExamStateEnum.Inspected:
        return "已体检";
      default:
        return "";
    }
  }

  MaterialColor examStateColors(ExamStateEnum state) {
    switch (state) {
      case ExamStateEnum.Unchecked:
        return Colors.grey;
      case ExamStateEnum.Invalid:
        return Colors.red;
      case ExamStateEnum.Inspected:
        return Colors.green;
      default:
        return Colors.blue;
    }
  }
}
